.. :changelog:

History
-------

0.9.2 (2019-02-25)
++++++++++++++++++

* correct field name in ACC table
* add more fielads in ACC and CDR tables
* admin tweaks

0.9.1 (2019-01-30)
++++++++++++++++++

* upload fixtures from migration for initial setup
* new table for statistics

0.9.0 (2018-11-15)
++++++++++++++++++

* First release on PyPI.
